You are viewing a plain text version of this content. The canonical link for it is here.
Posted to pubscribe-dev@ws.apache.org by ip...@apache.org on 2005/03/12 00:57:32 UTC

svn commit: r157179 - in incubator/hermes/trunk/src/java/org/apache/ws: eventing/RemoteSubscriptionHome.java notification/topics/topicexpression/impl/TopicExpressionException.java

Author: ips
Date: Fri Mar 11 15:57:31 2005
New Revision: 157179

URL: http://svn.apache.org/viewcvs?view=rev&rev=157179
Log:
fixed compile error caused by API change in Apollo

Modified:
    incubator/hermes/trunk/src/java/org/apache/ws/eventing/RemoteSubscriptionHome.java
    incubator/hermes/trunk/src/java/org/apache/ws/notification/topics/topicexpression/impl/TopicExpressionException.java

Modified: incubator/hermes/trunk/src/java/org/apache/ws/eventing/RemoteSubscriptionHome.java
URL: http://svn.apache.org/viewcvs/incubator/hermes/trunk/src/java/org/apache/ws/eventing/RemoteSubscriptionHome.java?view=diff&r1=157178&r2=157179
==============================================================================
--- incubator/hermes/trunk/src/java/org/apache/ws/notification/topics/topicexpression/impl/TopicExpressionException.java (original)
+++ incubator/hermes/trunk/src/java/org/apache/ws/notification/topics/topicexpression/impl/TopicExpressionException.java Fri Mar 11 15:57:31 2005
@@ -15,13 +15,13 @@
  */
 package org.apache.ws.notification.topics.topicexpression.impl;
 
-
 /**
  * This is a basic exception raised by <code>TopicExpressionEngine</code> or
  * <code>TopicExpressionEvaluator</code>.
  */
-public class TopicExpressionException extends Throwable
+public class TopicExpressionException extends Exception
 {
+
     /**
      * Creates a TopicExpressionException without error message.
      */
@@ -60,4 +60,5 @@
     {
         super("", exception);
     }
+
 }



---------------------------------------------------------------------
To unsubscribe, e-mail: hermes-dev-unsubscribe@ws.apache.org
For additional commands, e-mail: hermes-dev-help@ws.apache.org
--- incubator/hermes/trunk/src/java/org/apache/ws/eventing/RemoteSubscriptionHome.java (original)
+++ incubator/hermes/trunk/src/java/org/apache/ws/eventing/RemoteSubscriptionHome.java Fri Mar 11 15:57:31 2005
@@ -15,28 +15,35 @@
  */
 package org.apache.ws.eventing;
 
-import org.xmlsoap.schemas.ws.x2004.x08.eventing.SubscribeDocument;
-
-import edu.berkeley.cs.db.yfilter.filter.*;
-import edu.berkeley.cs.db.yfilterplus.queryparser.*;
-import edu.berkeley.cs.db.yfilterplus.xmltree.*;
-
-import org.apache.axis.message.*;
-
-
+import edu.berkeley.cs.db.yfilter.filter.EXfilterBasic;
+import edu.berkeley.cs.db.yfilter.filter.SystemGlobals;
+import edu.berkeley.cs.db.yfilterplus.queryparser.Query;
+import edu.berkeley.cs.db.yfilterplus.queryparser.XPQuery;
+import edu.berkeley.cs.db.yfilterplus.xmltree.XMLTree;
+import org.apache.commons.logging.Log;
+import org.apache.commons.logging.LogFactory;
+import org.apache.ws.addressing.EndpointReference;
+import org.apache.ws.addressing.XmlBeansEndpointReference;
+import org.apache.ws.resource.InvalidResourceKeyException;
+import org.apache.ws.resource.JndiConstants;
+import org.apache.ws.resource.RemoveCallback;
+import org.apache.ws.resource.RemoveNotSupportedException;
+import org.apache.ws.resource.Resource;
+import org.apache.ws.resource.ResourceException;
+import org.apache.ws.resource.ResourceKey;
+import org.apache.ws.resource.ResourceUnknownException;
 import org.apache.ws.resource.impl.SimpleTypeResourceKey;
-import org.apache.ws.resource.*;
-import org.apache.ws.addressing.*;
-import org.xmlsoap.schemas.ws.x2004.x08.addressing.*;
-import org.apache.xmlbeans.XmlObject;
-import org.apache.xmlbeans.XmlCursor;
 import org.apache.ws.util.XmlBeanUtils;
+import org.apache.xmlbeans.XmlCursor;
+import org.apache.xmlbeans.XmlObject;
+import org.xmlsoap.schemas.ws.x2004.x08.addressing.AttributedURI;
+import org.xmlsoap.schemas.ws.x2004.x08.addressing.EndpointReferenceDocument;
+import org.xmlsoap.schemas.ws.x2004.x08.addressing.EndpointReferenceType;
+import org.xmlsoap.schemas.ws.x2004.x08.addressing.ReferencePropertiesType;
+import org.xmlsoap.schemas.ws.x2004.x08.eventing.SubscribeDocument;
 
 import javax.xml.namespace.QName;
 
-import org.apache.commons.logging.Log;
-import org.apache.commons.logging.LogFactory;
-
 public class RemoteSubscriptionHome extends org.apache.ws.resource.impl.AbstractResourceHome{
     private static final Log LOG = LogFactory.getLog( RemoteSubscriptionHome.class.getName() );
     
@@ -99,24 +106,24 @@
         }
     }
     
-    public Resource find( ResourceKey key ) throws ResourceException, NoSuchResourceException, InvalidResourceKeyException{
+    public Resource find( ResourceKey key ) throws ResourceException {
         LOG.info("find "+ key.getValue()+" have "+subs.size());
         if(subs.containsKey(key.getValue())){
             RemoteSubscription s = (RemoteSubscription)subs.get(key.getValue());
             return s;
         }else
-            throw new NoSuchResourceException();
+            throw new ResourceUnknownException();
     }
     /**
      * Removes a resource. If the resource implements the {@link RemoveCallback RemoveCallback} interface, the
      * implementation must invoke the remove() operation on the resource itself.
      *
      * @throws NoSuchResourceException     if no resource exists with the given key
      * @throws InvalidResourceKeyException if the resource key is invalid.
      * @throws RemoveNotSupportedException if remove operation is not supported.
      * @throws ResourceException           if any other error occurs.
      */
-    public void remove( ResourceKey key ) throws ResourceException, NoSuchResourceException, InvalidResourceKeyException, RemoveNotSupportedException{
+    public void remove( ResourceKey key ) throws ResourceException {
         LOG.info("removeSubscription : "+key.getValue());
         Query q=(Query)queriesBack.get(key.getValue());
         yfilter.deleteQuery(q,q.getQueryId());
@@ -99,24 +106,24 @@
      * implementation must invoke the remove() operation on the resource itself.
      *
-     * @throws NoSuchResourceException     if no resource exists with the given key
+     * @throws ResourceUnknownException    if no resource exists with the given key
      * @throws InvalidResourceKeyException if the resource key is invalid.
      * @throws RemoveNotSupportedException if remove operation is not supported.

Modified: incubator/hermes/trunk/src/java/org/apache/ws/notification/topics/topicexpression/impl/TopicExpressionException.java
URL: http://svn.apache.org/viewcvs/incubator/hermes/trunk/src/java/org/apache/ws/notification/topics/topicexpression/impl/TopicExpressionException.java?view=diff&r1=157178&r2=157179
==============================================================================